@@ -110,7 +110,11 @@ class Feed(list):
         newlist = []
         for entry in entries:
 
-            if entry in self:
+            # This checks existence in newlist as well to avoid
+            # duplicate items on feeds with duplicates in them.
+            # (i.e. broken)
+
+            if entry in self and entry not in newlist:
                 centry = self[self.index(entry)]
                 if (not centry.updated) and\
                     (centry["canto_state"] != entry["canto_state"]):
@@ -158,7 +162,9 @@ class Feed(list):
                 newlist.append(story.Story(nentry, self.path, updated))
 
         del self[:]
-        list.extend(self, filter(self.filter, newlist))
+        for item in newlist:
+            if not self.filter or self.filter(self, item):
+                list.append(self, item)
 
     # Merging items means that they're unvalidated and unfiltered. This is
     # used when story objects are read in from a pipe.
