@@ -181,7 +181,6 @@ class Main():
 
         fixedtags = self.ph.recv()
         
-        signal.signal(signal.SIGCHLD, self.chld)
         self.ph.kill_process()
         for i, f in enumerate(self.cfg.feeds):
             self.cfg.feeds[i].tags = fixedtags[i]
@@ -257,7 +256,11 @@ class Main():
         for f in self.cfg.feeds:
             del f[:]
 
-        self.ph.start_process(self.cfg)
+        if not self.ph.start_process(self.cfg):
+            print "Unable to start secondary process. Bailing"
+            sys.exit(-1)
+
+        signal.signal(signal.SIGCHLD, self.chld)
         self.update(1, self.cfg.feeds, PROC_BOTH)
 
         # At this point we know that we're going to actually launch
@@ -291,8 +294,11 @@ class Main():
         self.cfg.height, self.cfg.width = self.cfg.stdscr.getmaxyx()
 
         # Init colors
-        for i, (fg, bg) in enumerate(self.cfg.colors):
-            curses.init_pair(i + 1, fg, bg)
+        try:
+            for i, (fg, bg) in enumerate(self.cfg.colors):
+                curses.init_pair(i + 1, fg, bg)
+        except:
+            self.cfg.log("Unable to init curses color pairs!")
 
         self.cfg.log("Curses initialized.")
     
@@ -369,30 +375,30 @@ class Main():
 
                     r = self.ph.recv(True, 0.01)
                     if r:
-                        feed = [ f for f in self.cfg.feeds if f.URL == r[0]][0]
-
-                        old = []
-                        for gf, tf, s, l in r[3]:
-                            if not l:
+                        feed = [ f for f in self.cfg.feeds if f.URL == r[1]][0]
+                        if r[0] == PROC_UPDATE:
+                            old = []
+                            for gf, tf, s, l in r[4]:
+                                if not l:
+                                    old.append((gf, tf, s, l))
+                                    continue
+                                for i, oldidx in enumerate(l):
+                                    l[i] = feed[oldidx]
                                 old.append((gf, tf, s, l))
-                                continue
-                            for i, oldidx in enumerate(l):
-                                l[i] = feed[oldidx]
-                            old.append((gf, tf, s, l))
 
-                        feed.merge(r[1])
+                            feed.merge(r[2])
 
-                        new = []
-                        for gf, tf, s, l in r[2]:
-                            if not l:
-                                new.append((gf, tf, s, None))
-                                continue
-                            for i, newidx in enumerate(l):
-                                l[i] = (feed[newidx], newidx)
-                            new.append((gf, tf, s, l))
+                            new = []
+                            for gf, tf, s, l in r[3]:
+                                if not l:
+                                    new.append((gf, tf, s, None))
+                                    continue
+                                for i, newidx in enumerate(l):
+                                    l[i] = (feed[newidx], newidx)
+                                new.append((gf, tf, s, l))
 
-                        self.gui.alarm(new, old)
-                        self.gui.draw_elements()
+                            self.gui.alarm(new, old)
+                            self.gui.draw_elements()
                         feed.qd = False
                     continue
 
@@ -507,6 +513,7 @@ class Main():
             self.cfg.wait_for_pid = 0
             signal.signal(signal.SIGALRM, self.alarm)
             signal.signal(signal.SIGWINCH, self.winch)
+            self.alarmed = 1
             self.resize = 1
 
     # Back to better practices. =)
