@@ -29,6 +29,7 @@ class Story():
         self.ondisk = None
         self.d = d
         self.sel = 0
+        self.in_reader = 0
     
     def __eq__(self, other):
         if self["id"] != other["id"]:
@@ -52,6 +53,9 @@ class Story():
     # particular feed entry.
 
     def get_ufp_entry(self):
+        if not self.ufp_path:
+            return {}
+
         try:
             f = open(self.ufp_path, "r")
             try:
